@@ -80,7 +80,7 @@ class APIRequestor:
     def _get_proxies(self, proxy_url):
         proxies = None
         if proxy_url:
-            proxies = {"http": proxy_url}
+            proxies = {"http": proxy_url, "https": proxy_url}
         return proxies
 
     def request_raw(self, method, url, params={}, supplied_headers=None):
